@@ -1,25 +1,19 @@
 ## ranked probability score
-
 rps <- function(obs, pred, baseline = NULL){
+
 ## pred is a matrix.  each column the prob of a given outcome
 ## obs is a vector with the number of the column that occured.  
 
-  
-##pred <- DAT[, 5:7]
-##obs <- DAT[,4]
+nr <- nrow(pred)
 
-##obs2 <- rep(1, length(obs) )
-##obs2[obs > 0.2] <- 2
-##obs2[obs > 4.4] <- 3
 
-##obs <- obs2
-  
 ################
 id   <- is.finite(obs) & is.finite(apply(pred, 1, sum) )
 obs  <- obs[id]
-pred <- pred[id,]
+pred <- matrix(pred[id,], nrow = nr )
 ########
 
+
 OBS <- matrix(0, nrow = length(obs), ncol = ncol(pred) )
 
 ## a loop, but it seems quick enough
@@ -29,17 +23,18 @@ OBS[i,obs[i] ]  <- 1
 
 OBS2 <- OBS
 
+
 for(i in 1:ncol(OBS) ){
-OBS2[,i] <- apply(as.matrix(OBS[, 1:i]), 1, sum)
+OBS2[,i] <- apply(matrix(OBS[, 1:i], nrow = nr), 1, sum)
 }
 
 PRED <- OBS
 for(i in 1:ncol(pred) ){
-PRED[,i] <- apply(as.matrix(pred[, 1:i]), 1, sum)
+PRED[,i] <- apply(matrix(pred[, 1:i], nrow = nr), 1, sum)
 }
 
 
-  
+
 RPS <- mean( apply( ( PRED - OBS2)^2,1, sum)  )/ ( ncol(pred) -1 )
 ####
 
@@ -53,9 +48,10 @@ xxx <- apply(OBS, 2, sum)/ nrow(OBS) ## avg occurrence of each event
 
 PRED.climo <- OBS
 for(i in 1:ncol(pred.climo) ){
-PRED.climo[,i] <- apply(as.matrix(pred.climo[, 1:i]), 1, sum)
+PRED.climo[,i] <- apply(matrix(pred.climo[, 1:i], nrow = nr), 1, sum)
 }
 
+
 RPS.climo <- mean( apply( ( PRED.climo - OBS2)^2,1, sum)  )/ ( ncol(PRED.climo) -1 )
 
 RPSS <- 1 - RPS/RPS.climo
